function [c,ceq]=confun(x)

%% OPTIMIZATION, CHEMENG DEPT NTNU.
% Nonlinear constraints-Compact Sub-sea Separation system-Steady state.
% c -vector nonlinear inequality constraints
% ceq-vector nonlinear equality constraints
% x -vector of F2 F3.
% F2,F3 top stream split fraction on degasser, deliquidizer respectively.
% By Fahad Matovu, 2015.


% Parameters
p = par_css(); % parameter fnc for CSS system.


F2=x(1);
F3=x(2);

q_1=150; % inlet flow rate m3/h
f1=0.65; % inlet gas fraction

% Grav sep
[q_2,f2,q_3,beta_3]=mod_grav(q_1,f1);

c(1)=[f2-1]; % constraint
c(2)=[beta_3-1]; % constraint
c(3)=[-(1-beta_3).*q_3]; % constraint     

% Degas
[q_5,f5,q_4,beta_4]=mod_degas(q_3,beta_3,F2);

c(4)=[-(1-f5).*q_5]; % constraint
c(5)=[f5-1]; % constraint
c(6)=[beta_4-1]; % constraint

q_6=q_2 +q_5 % inlet stream to deliq 
q_g6=f2.*q_2 + f5.*q_5; % gas 
q_l6=(1-f2).*q_2 +(1-f5).*q_5; % liq

f6=q_g6./q_6 % inlet gas fraction

c(7)=[f6-1]; % constraint

% Deliq
[q_7,f7,q_8,beta_8]=mod_deliq(q_6,f6,F3);

c(8)=[f7-1]; % constraint
c(9)=[-(1-beta_8).*q_8]; % constraint

% To pump
q_g9=(1-beta_4).*q_4 + (1-beta_8).*q_8;
q_l9=beta_4.*q_4 + beta_8.*q_8;
q_9=q_g9 + q_l9;
beta_9=q_l9./q_9;
beta_alpha=-(beta_9 + f7)./2;

ceq = []; % non-linear equality constraints


end