function [q_7,f7,q_9,beta_9]=mod_comp(q_1,f1,F2,F3)

%% COMBINED MODEL FOR GRAVITY SEPARATOR,DEGASSER AND DELIQUIDIZER, CHEMENG DEPT NTNU.
% Modelling of Compact Sub-sea Separators(CSS)-Steady state.
% mod_comp(q_1,f1,F2,F3) predicts outlet stream flow rates and phase fractions. 
% q_1 inlet flow rate (m^3/h)-scalar or vector, f1 inlet gas fract and 
% F2,F3 top stream split fraction on degasser, deliquidizer respectively.
% By Fahad Matovu, 2015. 

% Parameters
p = par_css(); % parameter fnc for CSS system.

% Grav sep
[q_2,f2,q_3,beta_3]=mod_grav(q_1,f1)

% Degas
[q_5,f5,q_4,beta_4]=mod_degas(q_3,beta_3,F2)

q_6=q_2 +q_5 % inlet stream to deliq 
q_g6=f2.*q_2 + f5.*q_5; % gas 
q_l6=(1-f2).*q_2 +(1-f5).*q_5; % liq

f6=q_g6./q_6 % inlet gas fraction

% Deliq
[q_7,f7,q_8,beta_8]=mod_deliq(q_6,f6,F3)

% To pump
q_g9=(1-beta_4).*q_4 + (1-beta_8).*q_8; % gas
q_l9=beta_4.*q_4 + beta_8.*q_8; % liq
q_9=q_g9 + q_l9; % total flow rate
beta_9=q_l9./q_9; % liq vol fraction


end