function [q_5,f5,q_4,beta_4]=mod_degas(q_3,beta_3,F2)

%% DEGASSER MODEL, CHEMENG DEPT NTNU.
% Modelling of Compact Sub-sea Separators(CSS)-Steady state.
% mod_degas(q_3,beta_3,F2) predicts outlet stream flow rates and phase fractions. 
% q_3 inlet flow rate(m^3/h)-scalar or vector, beta_3 inlet liq fract and F2 (=q_5/q_3) top stream split fraction.
% By Fahad Matovu, 2015. 

% Parameters
p = par_css(); % parameter fnc for CSS system.

vdot2=q_3./3600;% q in m3/s
w=8.9*exp(-12*exp(-0.05.*q_3)); % angular frequency (Gompertz function)
t_axial= (pi*p.R^2*p.L_2)./vdot2; % bubble axial time

% Forced vortex(Solid body)
y=(log(p.r_g) - 4*(pi)^2*(t_axial.*(p.dp.^2)*(p.rho_g-p.rho_l).*(w.^2))/(18*p.mu_l));
r_l=exp(y); % critical bubble entrance position
  
eff=((r_l.^2-p.r_g^2)./(p.R^2-p.r_g^2)); % gas separation efficiency
q_gsep=(1-beta_3).*q_3.*((r_l.^2-p.r_g^2)./(p.R^2-p.r_g^2)); % gas separated

% Outlet streams and phase fractions

q_5=F2.*q_3; % top flow rate
q_l5=q_5-q_gsep; % liq out top
q_g5=q_5-q_l5; % gas out top

q_4=(1-F2).*q_3; % bottom flow rate

q_l4=beta_3.*q_3-q_l5; % liq out bottom
q_g4=(1-beta_3).*q_3-q_gsep; % gas out bottom

f5=q_g5./q_5; % gas fraction top
beta_4=q_l4./(q_4); % liq fraction bottom

% data_deg=[q_3' w' eff'  f5' beta_4'];
% save deg.dat data_deg -ASCII

% % Plotting
% 
% figure(1)
% subplot(2,2,1)
% plot(q_3,w)
% title('Plot of angular frequency')
% xlabel('Inlet flowrate Qi in m3/h')
% ylabel('angular frequency, w')
% grid on
% 
% subplot(2,2,2)
% plot(q_3,eff)
% title('Plot of gas sep efficiency')
% xlabel('Inlet flowrate Qi in m3/h')
% ylabel('sep.eff')
% grid on
% 
% subplot(2,2,3)
% plot(q_3,f5)
% title('Plot of gas quality top stream')
% xlabel('Inlet flowrate Qi in m3/h')
% ylabel('quality of gas, alpha')
% grid on
% 
% subplot(2,2,4)
% plot(q_3,beta_4)
% title('Plot of liquid quality bottom stream')
% xlabel('Inlet flowrate Qi in m3/h')
% ylabel('quality of liquid, Beta_l')
% grid on
% 
% % balances
% bal_g=(1-beta_3)*q_3-q_g5-q_g4
% bal_l=beta_3*q_3-q_l5-q_l4
end
