function [q_top,alpha,q_bottom,beta]=mod_deliq(Qi,f,F3)

%% DELIQUIDIZER MODEL, CHEMENG DEPT NTNU.
% Modelling of Compact Sub-sea Separators(CSS)-Steady state.
% mod_deliq(Qi,f,F3) predicts outlet stream flow rates and phase fractions. 
% Qi inlet flow rate (m^3/h)-scalar or vector, f inlet gas fract and F3 (=q_top/Qi) top stream split fraction.
% By Fahad Matovu, 2015. 

% Parameters
p = par_css(); % parameter fnc for CSS system.

dp_d=-0.6*(Qi)*1e-06 + 0.0002; % Droplet size distribution
vdot=(Qi)/3600;% q in m3/s
w=6.7*exp(-8.7*exp(-0.0372*Qi)); % angular velocity (Gompertz function)
t_axial= (pi*p.R_3^2*p.L_3)./vdot; % droplet axial time

y=(log(p.R_3)-(t_axial.*(dp_d.^2)*(p.rho_l-p.rho_g).*(w.^2))/(18*(p.mu_g)));
r_l=exp(y); % critical droplet entrance position

sep_eff=(1-(r_l/p.R_3).^2); % liq separation efficiency
q_lsep=(1-f).*Qi.*(1-(r_l/p.R_3).^2); % liq sep

% Outlet streams and phase fractions

q_top=F3.*Qi; % top flow rate
q_lot=(1-f).*Qi-q_lsep; % liq out top
q_got=q_top-q_lot; % gas out top

alpha=q_got./q_top; % gas fraction top

% Out of boot

q_bottom=Qi-q_top; % bottom flow rate
q_lob=(1-f).*Qi-q_lot; % liq out bottom
q_gob=q_bottom-q_lob; % gas out bottom

beta=q_lob./q_bottom; % liq fraction bottom

% % Experimental data for comparison for q(10:10:200)
% alpha_g=[0.826 0.837 0.850 0.864 0.915 0.964 0.976 0.982 0.985 0.985...
%     0.984 0.981 0.977 0.970 0.963 0.954 0.943 0.931 0.918 0.903 ];

% Save data for plotting
% data_deliq=[Qi' w' sep_eff' alpha' alpha_g' beta']
% save deliq.dat data_deliq -ASCII

% % Plotting
% 
% figure(1)
% subplot(2,2,1)
% plot(Qi,w)
% title('Plot of angular velocity')
% xlabel('total volumetric flowrate Qi in m3/h')
% ylabel('angular velocity, w')
% grid on
% 
% subplot(2,2,2)
% plot(Qi,sep_eff)
% title('Plot of sep. eff liq')
% xlabel('total volumetric flowrate Qi in m3/h')
% ylabel(' Liq sep.eff')
% grid on
% 
% subplot(2,2,3)
% plot(Qi,alpha)
% title('Plot of quality of gas')
% xlabel('total volumetric flowrate Qi in m3/h')
% ylabel('quality of gas, alpha')
% grid on
% 
% % hold on
% % scatter(Qi,alpha_g,'.') % data points for comparison
% % legend('GVF','data','Location','SouthEast')
% 
% subplot(2,2,4)
% plot(Qi,beta)
% title('Plot of quality of liquid')
% xlabel('total volumetric flowrate Qi in m3/h')
% ylabel('quality of liquid, beta')
% grid on
% 
% % check balances
% bal_g=f*Qi-q_got-q_gob
% bal_l=(1-f)*Qi-q_lot-q_lob

end
